function Results = CalcBulkFrac_mol_based(n_mol_solute,n_mol_H2O,D_m,Gamma_mol_per_m2,K)

% Calculate surfactant partioning between bulk and surface

close all


Area_m2 = pi * D_m.^2; 

% surfactant partitioning, Topping 2010
a_mol = Area_m2 * Gamma_mol_per_m2 * K...
    - n_mol_H2O * K...
    - n_mol_solute * K;

b_mol = n_mol_solute * K...
    - n_mol_solute - n_mol_H2O...
    - Area_m2 * Gamma_mol_per_m2 * K;

x_bulk_solute = (-b_mol - (b_mol.^2 - 4 * a_mol...
    * n_mol_solute).^0.5) ./ (2 * a_mol); % bulk organic solute


n_bulk_mol = x_bulk_solute .* n_mol_H2O ./(1 - x_bulk_solute); % bulk organic solute
BulkFrac = n_bulk_mol / n_mol_solute;



% Return results
Results.BulkFrac = BulkFrac;
Results.n_mol_solute = n_mol_solute; % total organic solute mol
Results.n_mol_H2O = n_mol_H2O;
Results.x_bulk_solute = x_bulk_solute;
Results.n_bulk_mol = n_bulk_mol;


end