function Fig2()

Param = SetParam();
Const = GetConst();


% Reset parameters
Param.Delta_aP_ug_per_m3 = 100; % Amount of reacted aP (ug/m3)
Param.InorgSeed_VolFrac= 0.0; % Volume fraction of inorganic seed particles
Param.InorgKappa = 0.61; % ammonium sulfate, Petters and Kreidenweis 2007
Param.Ddry_nm = 100;% Parameters for CCN calculation






% Volatility determines partitioning.
% Volatility + O/C determine molecular formula (nC,nH,nO), and hence
% intrinsic kappa.
Result = CalcIntrinsicKappa2DVBS(Param,Const);


% Apparent kappa calculation considering solubility and int_kappa
% distribution
Result = CalcApparentKappa(Param,Const,Result);



% Plot results
close all
LineWidth = 2;
FontSize = 15;

Fig1 = figure;
Fig1.Units = 'normalized';
Fig1.Position = [0.5 0.3 0.4 0.7];
ax1 = subplot(3,2,[1 2]);
ax2 = subplot(3,2,3);
ax3 = subplot(3,2,4);
ax4 = subplot(3,2,5);
ax5 = subplot(3,2,6);


% 2D-VBS distribution
x_sub = log10(Param.CStarBasis);
y_sub = Param.O2CBasis;
image(ax1,x_sub,y_sub,Result.OrgPMvolFrac_2D,'CDataMapping','scaled')
set(gcf,'CurrentAxes',ax1)
ax = gca;
ax.YDir = 'normal';
ax.FontSize = 20;
colormap(flipud(gray)) % reversed gray scale
caxis([0 0.3]) % color scale range
c = colorbar;
c.Label.String = 'Org PM vol fraction';
set(c,'fontsize',FontSize);
set(c,'linewidth',LineWidth);
xlim([-5 9])
ylim([0 1])
xlabel('log C*')
ylabel('O/C')

hold on
[Ckappa,hkappa] = contour(ax1,x_sub,y_sub,Result.IntrinsicKappa_2D,'k-');
clabel(Ckappa,hkappa,'FontSize',FontSize)
vLevel = [0.001 0.01 0.1];
[Csolubility,hsolubility] = contour(ax1,x_sub,y_sub,Result.C_v_per_v_2D,vLevel,'k--');
clabel(Csolubility,hsolubility,'FontSize',FontSize)

dim = [.7 .6 .3 .3];
str = {Param.Species;  
    strcat('OA:',num2str(Result.OrgPMmass_ug_m3,'%.1f'),'\mug m^{-3}')};
ha = annotation('textbox',dim,'String',str,'FitBoxToText','on','FontSize',FontSize);
ha.BackgroundColor = 'w';


% Kohler curve
sub1 = semilogx(ax2,Result.D_m * 1e9, Result.SatRatio,'r-');
sub1.LineWidth = LineWidth;
hold (ax2,'on')
semilogx(ax2,Result.D_m * 1e9, Result.S_solubilityOnly,'k','LineWidth',LineWidth);
semilogx(ax2,[Result.D_critical_m * 1e9 Result.D_critical_m * 1e9],[0.9 1.1],'r--',...
    'LineWidth',LineWidth)
semilogx(ax2,[Result.D_critical_m_solubilityOnly * 1e9 Result.D_critical_m_solubilityOnly * 1e9],[0.9 1.1],'k--',...
    'LineWidth',LineWidth)
%semilogx(ax2,[50 5000],[Result.Sc Result.Sc],'r--','LineWidth',LineWidth)
%semilogx(ax2,[50 5000],[Result.Sc_solubilityOnly Result.Sc_solubilityOnly],'k--','LineWidth',LineWidth)



xlim(ax2,[50 5000])
ylim(ax2,[1 1.01])
xlabel(ax2,'Droplet diameter [nm]')
ylabel(ax2,'Saturation ratio')
legend(ax2,'Full partition','Solubility only','Location','northeast');



% Surface tension
sub2 = semilogx(ax4,Result.D_m * 1e9, Result.Sigma_withPartition_J_per_m2,'r-');
sub2.LineWidth = LineWidth;
xlim(ax4,[50 5000])
ylim(ax4,[0.04 0.075])
xlabel(ax4,'Droplet diameter [nm]')
ylabel(ax4,'Surface tension [J m^{-2}]')
hold (ax4,'on')
% semilogx(ax4,[Result.D_critical_m * 1e9 Result.D_critical_m * 1e9],[0 0.1],'r--','LineWidth',LineWidth)
% semilogx(ax4,[Result.D_critical_m_solubilityOnly * 1e9 Result.D_critical_m_solubilityOnly * 1e9]...
%     ,[0 0.1],'k--','LineWidth',LineWidth)

semilogx(ax4,[50 5000],[0.072 0.072],'k','LineWidth',LineWidth)



% Phase partition (Full partition)
set(gcf,'CurrentAxes',ax3)
axis auto
ax3 = gca;
h = area(ax3, Result.D_m * 1e9,...
    [Result.Fcore_Vol_weighted ...
    Result.Fbulk_Vol_weighted...
    Result.Fsurf_Vol_weighted]);
set (ax3, 'Xscale', 'log');
h(1).FaceColor = [.5 .5 .5];
h(2).FaceColor = 'c';
h(3).FaceColor = 'y';
legend('Non-aqueous','Aqueous','Surface','Location','southeast');
xlim(ax3,[50 5000])
ylim(ax3,[0 1])
hold (ax3,'on')
semilogx(ax3,[Result.D_critical_m * 1e9 Result.D_critical_m * 1e9],[0 1],'r--','LineWidth',LineWidth)

xlabel(ax3,'Droplet diameter [nm]')
ylabel(ax3,'Org solute phase fraction')


% Phase partition (solubility only)
set(gcf,'CurrentAxes',ax5)
axis auto
ax5 = gca;
F_aqueous_solubilityOnly = 1- Result.Fcore_solubilityOnly;
h = area(ax5, Result.D_m * 1e9,...
    [Result.Fcore_solubilityOnly ...
    F_aqueous_solubilityOnly]);
set (ax5, 'Xscale', 'log');
h(1).FaceColor = [.5 .5 .5];
h(2).FaceColor = 'c';
legend('Non-aqueous','Aqueous','Location','southeast');
xlim(ax5,[50 5000])
ylim(ax5,[0 1])
hold (ax5,'on')
semilogx(ax5,[Result.D_critical_m_solubilityOnly * 1e9 Result.D_critical_m_solubilityOnly * 1e9],[0 1],'k--'...
    ,'LineWidth',LineWidth)

xlabel(ax5,'Droplet diameter [nm]')
ylabel(ax5,'Org solute phase fraction')





ax1.FontSize = FontSize;
ax1.LineWidth = LineWidth;
ax2.FontSize = FontSize;
ax2.LineWidth = LineWidth;
ax3.FontSize = FontSize;
ax3.LineWidth = LineWidth;
ax4.FontSize = FontSize;
ax4.LineWidth = LineWidth;
ax5.FontSize = FontSize;
ax5.LineWidth = LineWidth;



box(ax2,'on')
box(ax4,'on')


end