function Fig3()

close all

CarboxylicAcid = [... % Gamma_mol_per_m2, K
    1.16E-06	8.63E+01	%	oxalic	LeeHildemann2014
    3.3E-06     5.77E+01	%	malonic	Topping2010
    2.0E-06     9.47E+01	%	malonic	LeeHildemann2014
    1.35E-06	3.72E+02	%	succinic	LeeHildemann2014
    1.53E-06	1.75E+02	%	succinic	Gaman2004
    3.18E-06	1.59E+01	%	succinic	Svenningsson2006
    5.0E-07     1.05E+03	%	glutaric	Topping2010
    1.7E-06     6.03E+02	%	glutaric	LeeHildemann2014
    2.67E-06	1.90E+02	%	glutaric	Gaman2004
    5.8E-06     2.28E+01	%	malic	Topping2010
    2.6E-06     2.62E+04	%	pinonic	Topping2010
    ];

Aldehyde = [...
    4.81E-07	5.46E+04	%	Acetaldehyde	McNeil2014
    3.13E-06	2.15E+03	%	AcetaldehydeAS	McNeil2014
    1.44E-06	2.77E+03	%	FormaldehydeAS	McNeil2014
    3.01E-06	4.21E+02	%	MGLY	McNeil2014
    2.41E-06	1.40E+04	%	MGLY_NaCl	McNeil2014
    2.29E-06	2.33E+04	%	MGLY_AS	McNeil2014
    ];

Levoglucosan =[...
    3.4E-07	4.51E+01	%	Levoglucosan	Svenningsson2006
    ];

FulvicAcid = [...
    2.5E-06	3.59E+04	%	SR_fulvic	Topping2010
    3.4E-06	1.28E+03	%	fulvic	Svenningsson2006
    ];

LabMix = [...
    5.26E-06	2.80E+02	%	MIXSEA	Svenningsson2006
    2.10E-06	2.77E+03	%	MIXBIO	Svenningsson2006
    3.80E-06	4.27E+02	%	MIXPO	Svenningsson2006
    2.48E-06	8.88E+02	%	MIXORG	Svenningsson2006
    ];

Ambient = [...
    2.25E-06	3.49E+04	%	PoValley	Facchini1999
    2.04E-05	6.58E+02	%	MaceHead	Cavalli2004
    3.55E-04	1.59E+01	%	OceanicDOM	Moore2008
    ];

BBOA = [...
    3.34E-04	1.36E+01	%	Prescribed	Asa_Awuku2008
    8.66E-07	3.96E+02	%	Chamise0hr	Giordano2013
    1.72E-06	4.54E+01	%	Chamise2hr	Giordano2013
    3.41E-06	5.31E+01	%	Chamise4hr	Giordano2013
    1.07E-06	3.81E+02	%	Mazanita0hr	Giordano2013
    2.90E-06	1.23E+01	%	Mazanita1hr	Giordano2013
    1.76E-06	4.12E+01	%	Mazanita3hr	Giordano2013
    2.66E-06	2.01E+00	%	Mazanita4hr	Giordano2013
    ];

Fig = figure;
FontSize = 20;
MarkerSize = 10;
Fig.Units = 'normalized';
Fig.Position = [0.5 0.3 0.3 0.3];


loglog(CarboxylicAcid(:,2), CarboxylicAcid(:,1),'k^','MarkerFaceColor','y','MarkerSize',MarkerSize)
hold on

loglog(Aldehyde(:,2), Aldehyde(:,1),'kd','MarkerFaceColor','b','MarkerSize',MarkerSize)
loglog(Levoglucosan(:,2), Levoglucosan(:,1),'k<','MarkerFaceColor','g','MarkerSize',MarkerSize)
loglog(FulvicAcid(:,2), FulvicAcid(:,1),'k>','MarkerSize',MarkerSize,'MarkerFaceColor','m')
loglog(LabMix(:,2), LabMix(:,1),'ko','MarkerSize',MarkerSize)
loglog(Ambient(:,2), Ambient(:,1),'kV','MarkerFaceColor','c','MarkerSize',MarkerSize)
loglog(BBOA(:,2), BBOA(:,1),'ks','MarkerFaceColor','r','MarkerSize',MarkerSize)

% Choice of an atmospherically relevant range
Gamma_min_mol_per_m2 = 3e-7;
Gamma_max_mol_per_m2 = 7e-6;
K_min = 2;
K_max = 6e4;

p=patch([K_min K_max K_max K_min],[Gamma_min_mol_per_m2 Gamma_min_mol_per_m2...
    Gamma_max_mol_per_m2 Gamma_max_mol_per_m2],[.5 .5 .5]);
p.EdgeColor = 'none';
set(p,'FaceAlpha',0.3);

legend('Carboxylic acids','Small aldehydes','Levoglucosan','Fulvic acid','Organic mixture',...
    'Ambient','Biomass burning OA')
xlabel('K^{\prime}')
ylabel('\Gamma^{max\prime} [mol m^{-2}]')
ax = gca;
ax.FontSize = FontSize;
xlim([1e0 2e5])
ylim([1e-7 1e-3])



end