function ApparentKappa = Sc_and_Ddry_2_kappa(Sc,A_m,Ddry_m)
% Iteratively calculate kappa without using the approximate form


logD_m = -9:0.01:-5; % logarithmically spaced diameter
D_m = 10.^logD_m';


% Initial guess using the approximation
KappaApprox = 4*A_m^3 / (27*Ddry_m^3*(log(Sc))^2);


% Calculate using Khler curve
Dlogic = D_m > Ddry_m;

Err =1;
maxErr = 1e-8;
Delta = 1.0005;

KappaIteration = KappaApprox; % Initialize

iLoop = 1;

while Err > maxErr % The loop varies kappa until max S matches Sc
    
    S= (D_m.^3 - Ddry_m^3) ./ (D_m.^3 - Ddry_m^3 * (1 - KappaIteration))...
        .* exp(A_m ./D_m);
    S = S .* Dlogic; % Remove points for D < Ddry
    
    
    ScIteration = max(S);
    Err = (Sc - ScIteration)^2;
    
    if Err < maxErr % if the first guess is good enough
        break
    end
    
    if ScIteration < Sc
        KappaIteration = KappaIteration / Delta ;
    else
        KappaIteration = KappaIteration * Delta ;
    end
      
     if iLoop > 1000       
%          text = 'Kappa iteration stopped at %d; initial guess %d';
%         sprintf(text,KappaIteration,KappaApprox)        
        break 
    end    
    iLoop = iLoop + 1;
    
end


ApparentKappa = KappaIteration;


end