function Param = SetParam()
% Set experimental parameters

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Parameters for individual simulation
Param.Species = '\alpha-pinene';% Specify species.  The default is alpha pinene (\alpha-pinene) from Donahue et al., ACP, 2012.
                                %'ROG_Murphy' = Table 2 in Murphy et al., ACP, 2012
Param.Delta_aP_ug_per_m3 = 100; % Amount of reacted aP (ug/m3)
Param.Delta_ROG_Murphy_ug_per_m3 = 100;%'ROG_Murphy' = Table 2 in Murphy et al., ACP, 2012
Param.InorgSeed_VolFrac= 0.0; % Volume fraction of inorganic seed particles
Param.InorgKappa = 0.61; % ammonium sulfate, Petters and Kreidenweis 2007
Param.T_K = 298.15; % Temp dependence not fully implemented. Use only 298.15 K for now.
Param.Ddry_nm = 100;% Parameters for CCN calculation
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%




% a-pinene ozonolysis carbon yield (sum to 1)
% Ref: Donahue, N. M., et al., A two-dimensional volatility basis set
%   - Part 2: Diagnostics of organic-aerosol evolution. Atmos. Chem. Phys. 2012, 12 (2), 615-634.

Param.CStarBasis = [1e-5 1e-4 1e-3 1e-2 1e-1 1e0 1e1 1e2 1e3 1e4 1e5 ...
    1e6 1e7 1e8 1e9];

Param.O2CBasis = [1; .9; .8; .7; .6; .5; .4; .3; .2; .1; 0];

Param.OScBasis = Param.O2CBasis*3 - 2;

Param.OCyield_2DVBS = [ ...
    
0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	; ...%1 +1.0
0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	; ...%.9 +0.7
0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	; ...%.8 +0.4
0	0	0	0	0.001	0	0	0	0	0	0	0	0	0	0	; ...%.7 +0.1
0	0	0	0	0.002	0.01	0.005	0	0	0	0	0	0	0	0	; ...%.6 -0.2
0	0	0	0	0	0.017	0.015	0.003	0	0	0	0	0	0	0	; ...%.5 -0.5
0	0	0	0	0	0.004	0.025	0.025	0.021	0.043	0.033	0	0	0	0	; ...%.4 -0.8
0	0	0	0	0	0	0.011	0.046	0.06	0.136	0.124	0.061	0	0	0	; ...%.3 -1.1
0	0	0	0	0	0	0	0.021	0.045	0.084	0.106	0.102	0	0	0	; ...%.2 -1.4
0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	;...%.1 -1.7
0	0	0	0	0	0	0	0	0	0	0	0	0	0	0	;...%0 -2

];


% Calculate total mass distribution of aP reaction products in 2D space
Param.aP_OC2OM = 120.1/136.23; % OC/OM ratio of C10H16
Param.Delta_aP_ugC_per_m3 = Param.Delta_aP_ug_per_m3 * Param.aP_OC2OM;
Param.OC_2DVBS = Param.Delta_aP_ugC_per_m3 * Param.OCyield_2DVBS; % Reacted a-pinene * OC yield in 2D

% Convert OC VBS to OM VBS
O2C = Param.O2CBasis;  % make O/C vector for readability
OM2OC = 1 + 1/12*(2 - O2C) + 16/12 * O2C; % Ref: Donahue et al.(2012), Heald et al. (2010)

for i_O2C = 1:size(O2C)
    Param.OM_2DVBS(i_O2C,:) = Param.OC_2DVBS(i_O2C,:) * OM2OC(i_O2C); % Note OM = PM + gas
end


Param.OM_2DVBS_yield_Murphy = [ ...                                 
        
    0	0	0	0	0	0	0	0	0	0	0	0	0	0	0
    0	0	0.004	0.01	0.018	0.01	0.004	0	0	0	0	0	0	0	0
    0	0	0.022	0.043	0.087	0.043	0.033	0	0	0	0	0	0	0	0
    0	0	0	0	0.48	0.143	0.191	0.096	0	0	0	0	0	0	0
    0	0	0	0	0	0.038	0.078	0.093	0.04	0	0	0	0	0	0
    0	0	0	0	0	0	0.04	0.099	0.059	0	0	0	0	0	0
    0	0	0	0	0	0	0	0	0	0	0	0	0	0	0
    0	0	0	0	0	0	0	0	0	0	0	0	0	0	0
    0	0	0	0	0	0	0	0	0	0	0	0	0	0	0
    0	0	0	0	0	0	0	0	0	0	0	0	0	0	0
    0	0	0	0	0	0	0	0	0	0	0	0	0	0	0
    ];


if strcmp(Param.Species,'ROG_Murphy')  % Yields are on a total mass basis. No need for OC --> OM conversion.
    
    Param.OM_2DVBS = Param.Delta_ROG_Murphy_ug_per_m3 * Param.OM_2DVBS_yield_Murphy;

end


% Construct 1D VBS
Param.VBS = sum(Param.OM_2DVBS); % OM = PM + gas



% Surfactant parameters
Param.Gamma_mol_per_m2 = 1.45e-6; % Midpoint = (3e-7 * 7e-6)^0.5
Param.K = 3.5e2 ; % Midpoint = (2 * 6e4)^0.5
Param.Sigma_min_J_per_m2 = 0.04; % Arbiturary chosen minimum surface tension


% Calculate alpha conversion term: C*[ug/m3] = (alpha)*Psat[atm]
Param.alpha = 1e6 / (8.21e-5) * 200 / Param.T_K; 
% Assume 200 g/mol. The molecular weight value has little effects on results
% (Daumit et al. Faraday Disc. 2013).


% Default Monte Carlo parameters
nO2CBins = size(Param.OM_2DVBS,1);
nCStarBins = size(Param.OM_2DVBS,2); % number of C* bins

Param.O2CBasis_Factor_rand = ones(1,nO2CBins); % no change by default
Param.CstarBasis_Factor_rand = ones(1,nCStarBins); % no change by default
Param.C_v_per_v_Factor_rand = ones(1,nO2CBins); % no change by default



end
