function Topping_Fig2b()

% Reproduce Fig.2b in
% Topping, D. An analytical solution to calculate bulk mole fractions for
% any number of components in aerosol droplets after considering partitioning 
% to a surface layer. Geoscientific Model Development 3, 635 (2010).

% Discrepancy from the paper is minor.

close all


% Constant
R_J_per_mol_K = 8.314;
SigmaH2O_J_per_m2 = 0.072; % surface tension of water

% Common parameters
T_K = 298.15;
SigmaMin_J_per_m2 = 0.03; %Assumed minimum sigma

Gamma_mol_per_m2_malic = 5.8e-6;
Gamma_mol_per_m2_cis_pinonic = 2.6e-6;
Gamma_mol_per_m2_malonic = 3.3e-6;
Gamma_mol_per_m2_glutaric = 5e-7;
Gamma_mol_per_m2_SRfulvic = 2.5e-6;

K_malic = 22.8; % adsorption equilibrium constant, dimensionless (1/activity)
K_cis_pinonic = 2.62e4;
K_malonic = 57.65;
K_glutaric = 1045.94;
K_SRfulvic = 35942.03;

Morg_kg_per_mol_malic = 134.09e-3;
Morg_kg_per_mol_cis_pinonic = 184.23e-3;
Morg_kg_per_mol_malonic = 104.06e-3;
Morg_kg_per_mol_glutaric = 132.11e-3;
Morg_kg_per_mol_SRfulvic = 732.59e-3;

Density_kg_per_m3_malic = 1609;
Density_kg_per_m3_cis_pinonic = 786;
Density_kg_per_m3_malonic = 1630;
Density_kg_per_m3_glutaric = 1316;
Density_kg_per_m3_SRfulvic = 1400;

MolarVol_m3_per_mol_malic = Morg_kg_per_mol_malic / Density_kg_per_m3_malic;
MolarVol_m3_per_mol_cis_pinonic = Morg_kg_per_mol_cis_pinonic / Density_kg_per_m3_cis_pinonic;
MolarVol_m3_per_mol_malonic = Morg_kg_per_mol_malonic / Density_kg_per_m3_malonic;
MolarVol_m3_per_mol_glutaric = Morg_kg_per_mol_glutaric / Density_kg_per_m3_glutaric;
MolarVol_m3_per_mol_SRfulvic = Morg_kg_per_mol_SRfulvic / Density_kg_per_m3_SRfulvic;
MolarVol_m3_per_mol_H2O = 18.02e-3 / 1e3;

% equimolar mixture of five components
Total_MolarVol_m3_per_mol = 1/5 * (... 
    MolarVol_m3_per_mol_malic + ...
    MolarVol_m3_per_mol_cis_pinonic + ...
    MolarVol_m3_per_mol_malonic + ...
    MolarVol_m3_per_mol_glutaric + ...
    MolarVol_m3_per_mol_SRfulvic);

% Calculate volume fractions for using Kappa-Kohler later
VolFrac_malic = 1/5 * MolarVol_m3_per_mol_malic /...
    Total_MolarVol_m3_per_mol;
VolFrac_cis_pinonic = 1/5 * MolarVol_m3_per_mol_cis_pinonic /...
    Total_MolarVol_m3_per_mol;
VolFrac_malonic = 1/5 * MolarVol_m3_per_mol_malonic /...
    Total_MolarVol_m3_per_mol;
VolFrac_glutaric = 1/5 * MolarVol_m3_per_mol_glutaric /...
    Total_MolarVol_m3_per_mol;
VolFrac_SRfulvic = 1/5 * MolarVol_m3_per_mol_SRfulvic /...
    Total_MolarVol_m3_per_mol;

% Ideal Kappa
Kappa_malic = MolarVol_m3_per_mol_H2O / MolarVol_m3_per_mol_malic;
Kappa_cis_pinonic = MolarVol_m3_per_mol_H2O / MolarVol_m3_per_mol_cis_pinonic;
Kappa_malonic = MolarVol_m3_per_mol_H2O / MolarVol_m3_per_mol_malonic;
Kappa_glutaric = MolarVol_m3_per_mol_H2O / MolarVol_m3_per_mol_glutaric;
Kappa_SRfulvic = MolarVol_m3_per_mol_H2O / MolarVol_m3_per_mol_SRfulvic;

% No partition Kappa based on initial composition
Kappa_NP = VolFrac_malic * Kappa_malic...
        + VolFrac_cis_pinonic * Kappa_cis_pinonic...
        + VolFrac_malonic * Kappa_malonic...
        + VolFrac_glutaric * Kappa_glutaric...
        + VolFrac_SRfulvic * Kappa_SRfulvic;


% Make arrays for Fig.2b data
NumDdry = 15;
Ddry_m_array = linspace(100e-9,380e-9, NumDdry)';
sc_percent_aNP_sigmaNP = zeros(NumDdry,1);
sc_percent_aNP_sigmaP = zeros(NumDdry,1);
sc_percent_aP_sigmaP = zeros(NumDdry,1);
sc_percent_aNP_sigmaW = zeros(NumDdry,1);


for iD = 1:NumDdry
    
    Ddry_m = Ddry_m_array(iD);
    
    Results = Topping_BulkFrac(Ddry_m);
    
    % mol of each solute should be equal in the equimolar example
    n_mol_malic = pi/6 * Ddry_m^3 * VolFrac_malic / MolarVol_m3_per_mol_malic;
    n_mol_cis_pinonic = pi/6 * Ddry_m^3 * VolFrac_cis_pinonic / MolarVol_m3_per_mol_cis_pinonic;
    n_mol_malonic = pi/6 * Ddry_m^3 * VolFrac_malonic / MolarVol_m3_per_mol_malonic;
    n_mol_glutaric = pi/6 * Ddry_m^3 * VolFrac_glutaric / MolarVol_m3_per_mol_glutaric;
    n_mol_SRfulvic = pi/6 * Ddry_m^3 * VolFrac_SRfulvic / MolarVol_m3_per_mol_SRfulvic;
    n_mol_H2O = (Results.Vol_m3 - pi/6 * Ddry_m^3) / MolarVol_m3_per_mol_H2O;

    
    % Kelvin effect
    A_m_w = 4 * MolarVol_m3_per_mol_H2O * SigmaH2O_J_per_m2...
        /(R_J_per_mol_K * T_K); % assuming water surface tension
    
    Sigma_J_per_m2_NP = SigmaH2O_J_per_m2 - R_J_per_mol_K * T_K * (... % NP: no partitioning
        Gamma_mol_per_m2_malic...
        * log(1 + K_malic * n_mol_malic ./(n_mol_malic + n_mol_H2O)) + ...
        Gamma_mol_per_m2_cis_pinonic...
        * log(1 + K_cis_pinonic * n_mol_cis_pinonic ./(n_mol_cis_pinonic + n_mol_H2O)) + ...
        Gamma_mol_per_m2_malonic...
        * log(1 + K_malonic * n_mol_malonic ./(n_mol_malonic + n_mol_H2O)) + ...
        Gamma_mol_per_m2_glutaric...
        * log(1 + K_glutaric * n_mol_glutaric ./(n_mol_glutaric + n_mol_H2O)) + ...
        Gamma_mol_per_m2_SRfulvic...
        * log(1 + K_SRfulvic * n_mol_SRfulvic ./(n_mol_SRfulvic + n_mol_H2O))...
        );
    
    Sigma_J_per_m2_NP ... % NP: no partitioning
        (Sigma_J_per_m2_NP < SigmaMin_J_per_m2)=...
        SigmaMin_J_per_m2; % limit sigma minimum
    
    A_m_NP = 4 * MolarVol_m3_per_mol_H2O .* Sigma_J_per_m2_NP...
        /(R_J_per_mol_K * T_K);
    
    Sigma_J_per_m2_P = SigmaH2O_J_per_m2 - R_J_per_mol_K * T_K * (...
        Gamma_mol_per_m2_malic...
        * log(1 + K_malic * Results.x_bulk_malic) + ...
        Gamma_mol_per_m2_cis_pinonic...
        * log(1 + K_cis_pinonic * Results.x_bulk_cis_pinonic) + ...
        Gamma_mol_per_m2_malonic...
        * log(1 + K_malonic * Results.x_bulk_malonic) + ...
        Gamma_mol_per_m2_glutaric...
        * log(1 + K_glutaric * Results.x_bulk_glutaric) + ...
        Gamma_mol_per_m2_SRfulvic...
        * log(1 + K_SRfulvic * Results.x_bulk_SRfulvic)...
        );
    
    Sigma_J_per_m2_P ... % P: with partitioning
        (Sigma_J_per_m2_P < SigmaMin_J_per_m2)=...
        SigmaMin_J_per_m2; % limit sigma minimum
    
    A_m_P = 4 * MolarVol_m3_per_mol_H2O .* Sigma_J_per_m2_P...
        /(R_J_per_mol_K * T_K);
    
    % Raoult effect
    % See Petters and Kreidenweis 2013, eq.7
    Kappa_P = Results.BulkFrac_malic * VolFrac_malic * Kappa_malic...
        + Results.BulkFrac_cis_pinonic * VolFrac_cis_pinonic * Kappa_cis_pinonic...
        + Results.BulkFrac_malonic * VolFrac_malonic * Kappa_malonic...
        + Results.BulkFrac_glutaric * VolFrac_glutaric * Kappa_glutaric...
        + Results.BulkFrac_SRfulvic * VolFrac_SRfulvic * Kappa_SRfulvic;
        
    
    % Kohler curve
    
    S_aNP_sigmaNP = (Results.D_m.^3 - Ddry_m^3) ./ (Results.D_m.^3 - Ddry_m^3 * (1-Kappa_NP))...
        .* exp(A_m_NP./Results.D_m);
    
    S_aNP_sigmaP = (Results.D_m.^3 - Ddry_m^3) ./ (Results.D_m.^3 - Ddry_m^3 * (1-Kappa_NP))...
        .* exp(A_m_P./Results.D_m);
    
    S_aP_sigmaP = (Results.D_m.^3 - Ddry_m^3) ./ (Results.D_m.^3 - Ddry_m^3 * (1-Kappa_P))...
        .* exp(A_m_P./Results.D_m);
    
    S_aNP_sigmaW = (Results.D_m.^3 - Ddry_m^3) ./ (Results.D_m.^3 - Ddry_m^3 * (1-Kappa_NP))...
        .* exp(A_m_w./Results.D_m); % no partition in Raoult, water sigma
    
    sc_percent_aNP_sigmaNP(iD) = (max(S_aNP_sigmaNP) - 1)*100; % critical super saturation [%]
    sc_percent_aNP_sigmaP(iD) = (max(S_aNP_sigmaP) - 1)*100;
    sc_percent_aP_sigmaP(iD) = (max(S_aP_sigmaP) - 1)*100;
    sc_percent_aNP_sigmaW(iD) = (max(S_aNP_sigmaW) - 1)*100;
    
 
end


figure
LineWidth = 2;
FontSize = 15;
plot(Ddry_m_array /2 * 1e9, sc_percent_aNP_sigmaNP,'ro','LineWidth',LineWidth)
xlim([50 200])
ylim([0 0.45])
hold on
plot(Ddry_m_array /2 * 1e9, sc_percent_aNP_sigmaP,'bo','LineWidth',LineWidth)
plot(Ddry_m_array /2 * 1e9, sc_percent_aP_sigmaP,'ko','LineWidth',LineWidth)
plot(Ddry_m_array /2 * 1e9, sc_percent_aNP_sigmaW,'go','LineWidth',LineWidth)
ylabel('Critical supersaturation [%]')
xlabel('Dry radius (nm)')
ax = gca;
ax.FontSize = FontSize;
ax.LineWidth = LineWidth;
legend('aw_{No partitioning}\sigma_{ws No partitioning}',...
    'aw_{No partitioning}\sigma_{ws Partitioning}',...
    'aw_{Partitioning}\sigma_{ws Partitioning}',...
    'aw_{No partitioning}\sigma_{w}')


end